/**
 * Example of how you could re-use GROQ queries across different contexts with Javascript.
 * As your schema evolves, this pattern will be useful to keep your data in sync across all surfaces.
 */
export function getPostsQuery(extraFilter) {
    return /* groq */ `*[
      _type == "post" &&
      publishedAt < now()
      ${extraFilter ? `&& ${extraFilter}` : ''}
    ] | order(publishedAt desc) {
        title,
        slug,
        coverImage,
        _createdAt,
        _updatedAt,
        body,
    }`
  }

  
  // Insert the return component calling `getContent()` below
  /**
   * You can also re-use parts of projections as fragments.
   * In this case, we're defining that, to render an author card, we need their name, slug & image.
   */
  export const POST_CARD_FRAGMENT = `
  title,
  slug,
  coverImage,
  _createdAt,
  _updatedAt,
  body,
  `